@@ -755,6 +755,14 @@ class ArgparseBuilder:
             caption="Файл конфигурации",
             argtype="filename",
         )
+        self.add_argument(
+            cmdcompose_pptx,
+            "--do_dot_remove_accents",
+            help="do not remove accents.",
+            advanced=True,
+            caption="Не убирать знаки ударения",
+            action="store_true",
+        )
         cmdcompose_telegram = cmdcompose_filetype.add_parser("telegram")
         self.add_argument(
             cmdcompose_telegram,
@@ -808,6 +816,13 @@ class ArgparseBuilder:
             help="skip questions until N.",
             caption="Пропустить вопросы до N-го",
         )
+        self.add_argument(
+            cmdcompose_telegram,
+            "--disable_asterisks_processing",
+            type=int,
+            help="disable asterisks processing.",
+            caption="Не обрабатывать звёздочки",
+        )
         cmdcompose_add_stats = cmdcompose_filetype.add_parser("add_stats")
         self.add_argument(
             cmdcompose_add_stats,
